.. _spectral:

spectral
========

This module offers utilities for processing data cubes and related operations.

Module Overview
---------------

.. currentmodule:: wizard._processing.spectral

.. autofunction:: smooth_savgol
.. autofunction:: smooth_moving_average
.. autofunction:: smooth_butter_lowpass
.. autofunction:: spec_baseline_als
.. autofunction:: calculate_modified_z_score
.. autofunction:: get_ratio_two_specs
.. autofunction:: get_sub_tow_specs
.. autofunction:: signal_to_noise
.. autofunction:: del_leading_zeros
.. autofunction:: del_last_zeros